@@ -1,3 +1,5 @@
+from dataclasses import dataclass
+
 from PIL.ImageOps import pad
 
 
@@ -12,13 +14,16 @@ def split_image_horizontally(image, number_of_images):
         yield image.crop((0, y, image.width, y + height))
 
 
-def pad_ratio(image, size):
+def pad_ratio(image, size, cell_size=None):
     """Pad to fit given size. Keeps aspect ratio.
 
     """
 
+    if cell_size is None:
+        cell_size = (1, 2)
+
     image_ratio = image.width / image.height
-    size_ratio = size[0] / size[1] / 2
+    size_ratio = (size[0] * cell_size[0]) / (size[1] * cell_size[1])
 
     if image_ratio < size_ratio:
         width = int(image.height * size_ratio)
